@@ -5,6 +5,7 @@ use std::rc::Rc;
 use unicode_width::UnicodeWidthChar;
 
 use unicode_width::UnicodeWidthStr;
+use zellij_utils::data::StyleDeclaration;
 use zellij_utils::input::command::RunCommand;
 use zellij_utils::{
     data::{PaletteColor, Style},
@@ -762,6 +763,12 @@ impl Display for CharacterStyles {
     }
 }
 
+impl From<StyleDeclaration> for CharacterStyles {
+    fn from(declaration: StyleDeclaration) -> Self {
+        RESET_STYLES.foreground(Some(declaration.base.into()))
+    }
+}
+
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LinkAnchor {
     Start(u16),
@@ -977,7 +984,9 @@ pub fn render_first_run_banner(
         Some(run_command) => {
             let bold_text = RESET_STYLES.bold(Some(AnsiCode::On));
             let command_color_text = RESET_STYLES
-                .foreground(Some(AnsiCode::from(style.colors.green)))
+                .foreground(Some(AnsiCode::from(
+                    style.colors.text_unselected.emphasis_2,
+                )))
                 .bold(Some(AnsiCode::On));
             let waiting_to_run_text = "Waiting to run: ";
             let command_text = run_command.to_string();
@@ -1002,7 +1011,9 @@ pub fn render_first_run_banner(
             let ctrl_c_bare_text = "Ctrl-c";
             let controls_bare_text_fourth_part = "> exit";
             let controls_color = RESET_STYLES
-                .foreground(Some(AnsiCode::from(style.colors.orange)))
+                .foreground(Some(AnsiCode::from(
+                    style.colors.text_unselected.emphasis_0,
+                )))
                 .bold(Some(AnsiCode::On));
             let controls_line_length = controls_bare_text_first_part.len()
                 + enter_bare_text.len()
@@ -1054,7 +1065,9 @@ pub fn render_first_run_banner(
             let ctrl_c_bare_text = "Ctrl-c";
             let controls_bare_text_fourth_part = "> exit";
             let controls_color = RESET_STYLES
-                .foreground(Some(AnsiCode::from(style.colors.orange)))
+                .foreground(Some(AnsiCode::from(
+                    style.colors.text_unselected.emphasis_0,
+                )))
                 .bold(Some(AnsiCode::On));
             let controls_line_length = controls_bare_text_first_part.len()
                 + enter_bare_text.len()
