@@ -39,6 +39,7 @@ pub fn scrolling_inside_a_pane() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -55,6 +56,7 @@ pub fn scrolling_inside_a_pane() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -87,6 +89,7 @@ pub fn sixel_image_inside_terminal_pane() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -103,6 +106,7 @@ pub fn sixel_image_inside_terminal_pane() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let sixel_image_bytes = "\u{1b}Pq
         #0;2;0;0;0#1;2;100;100;0#2;2;0;100;0
@@ -135,6 +139,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -151,6 +156,7 @@ pub fn partial_sixel_image_inside_terminal_pane() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -177,6 +183,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -193,6 +200,7 @@ pub fn overflowing_sixel_image_inside_terminal_pane() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let pane_content = read_fixture("sixel-image-500px.six");
     terminal_pane.handle_pty_bytes(pane_content);
@@ -218,6 +226,7 @@ pub fn scrolling_through_a_sixel_image() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -234,6 +243,7 @@ pub fn scrolling_through_a_sixel_image() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..30 {
@@ -270,6 +280,7 @@ pub fn multiple_sixel_images_in_pane() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -286,6 +297,7 @@ pub fn multiple_sixel_images_in_pane() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -320,6 +332,7 @@ pub fn resizing_pane_with_sixel_images() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -336,6 +349,7 @@ pub fn resizing_pane_with_sixel_images() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -373,6 +387,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -389,6 +404,7 @@ pub fn changing_character_cell_size_with_sixel_images() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
     let mut text_to_fill_pane = String::new();
     for i in 0..5 {
@@ -431,6 +447,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -447,6 +464,7 @@ pub fn keep_working_after_corrupted_sixel_image() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
 
     let sixel_image_bytes = "\u{1b}PI AM CORRUPTED BWAHAHAq
@@ -487,6 +505,7 @@ pub fn pane_with_frame_position_is_on_frame() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -503,6 +522,7 @@ pub fn pane_with_frame_position_is_on_frame() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::frame(1));
@@ -579,6 +599,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -595,6 +616,7 @@ pub fn pane_with_bottom_and_right_borders_position_is_on_frame() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::shift(1, 1));
@@ -671,6 +693,7 @@ pub fn frameless_pane_position_is_on_frame() {
     let debug = false;
     let arrow_fonts = true;
     let styled_underlines = true;
+    let explicitly_disable_kitty_keyboard_protocol = false;
     let mut terminal_pane = TerminalPane::new(
         pid,
         fake_win_size,
@@ -687,6 +710,7 @@ pub fn frameless_pane_position_is_on_frame() {
         debug,
         arrow_fonts,
         styled_underlines,
+        explicitly_disable_kitty_keyboard_protocol,
     ); // 0 is the pane index
 
     terminal_pane.set_content_offset(Offset::default());
