@@ -152,12 +152,14 @@ pub enum PluginInstruction {
         keybinds: Option<Keybinds>,
         default_mode: Option<InputMode>,
         default_shell: Option<TerminalAction>,
+        was_written_to_disk: bool,
     },
     FailedToWriteConfigToDisk {
         file_path: Option<PathBuf>,
     },
     WatchFilesystem,
     ListClientsToPlugin(SessionLayoutMetadata, PluginId, ClientId),
+    ChangePluginHostDir(PathBuf, PluginId, ClientId),
     Exit,
 }
 
@@ -204,6 +206,7 @@ impl From<&PluginInstruction> for PluginContext {
                 PluginContext::FailedToWriteConfigToDisk
             },
             PluginInstruction::ListClientsToPlugin(..) => PluginContext::ListClientsToPlugin,
+            PluginInstruction::ChangePluginHostDir(..) => PluginContext::ChangePluginHostDir,
         }
     }
 }
@@ -866,12 +869,19 @@ pub(crate) fn plugin_thread_main(
                 keybinds,
                 default_mode,
                 default_shell,
+                was_written_to_disk,
             } => {
-                // TODO: notify plugins that this happened so that they can eg. rebind temporary keys that
-                // were lost
                 wasm_bridge
                     .reconfigure(client_id, keybinds, default_mode, default_shell)
                     .non_fatal();
+                // TODO: notify plugins that this happened so that they can eg. rebind temporary keys that
+                // were lost
+                if was_written_to_disk {
+                    let updates = vec![(None, None, Event::ConfigWasWrittenToDisk)];
+                    wasm_bridge
+                        .update_plugins(updates, shutdown_send.clone())
+                        .non_fatal();
+                }
             },
             PluginInstruction::FailedToWriteConfigToDisk { file_path } => {
                 let updates = vec![(
@@ -886,6 +896,11 @@ pub(crate) fn plugin_thread_main(
             PluginInstruction::WatchFilesystem => {
                 wasm_bridge.start_fs_watcher_if_not_started();
             },
+            PluginInstruction::ChangePluginHostDir(new_host_folder, plugin_id, client_id) => {
+                wasm_bridge
+                    .change_plugin_host_dir(new_host_folder, plugin_id, client_id)
+                    .non_fatal();
+            },
             PluginInstruction::Exit => {
                 break;
             },
