@@ -101,12 +101,26 @@ fn host_run_plugin_command(caller: Caller<'_, PluginEnv>) {
                         context,
                     ) => open_file_floating(env, file_to_open, floating_pane_coordinates, context),
                     PluginCommand::OpenTerminal(cwd) => open_terminal(env, cwd.path.try_into()?),
+                    PluginCommand::OpenTerminalNearPlugin(cwd) => {
+                        open_terminal_near_plugin(env, cwd.path.try_into()?)
+                    },
                     PluginCommand::OpenTerminalFloating(cwd, floating_pane_coordinates) => {
                         open_terminal_floating(env, cwd.path.try_into()?, floating_pane_coordinates)
                     },
+                    PluginCommand::OpenTerminalFloatingNearPlugin(
+                        cwd,
+                        floating_pane_coordinates,
+                    ) => open_terminal_floating_near_plugin(
+                        env,
+                        cwd.path.try_into()?,
+                        floating_pane_coordinates,
+                    ),
                     PluginCommand::OpenCommandPane(command_to_run, context) => {
                         open_command_pane(env, command_to_run, context)
                     },
+                    PluginCommand::OpenCommandPaneNearPlugin(command_to_run, context) => {
+                        open_command_pane_near_plugin(env, command_to_run, context)
+                    },
                     PluginCommand::OpenCommandPaneFloating(
                         command_to_run,
                         floating_pane_coordinates,
@@ -117,6 +131,16 @@ fn host_run_plugin_command(caller: Caller<'_, PluginEnv>) {
                         floating_pane_coordinates,
                         context,
                     ),
+                    PluginCommand::OpenCommandPaneFloatingNearPlugin(
+                        command_to_run,
+                        floating_pane_coordinates,
+                        context,
+                    ) => open_command_pane_floating_near_plugin(
+                        env,
+                        command_to_run,
+                        floating_pane_coordinates,
+                        context,
+                    ),
                     PluginCommand::SwitchTabTo(tab_index) => switch_tab_to(env, tab_index),
                     PluginCommand::SetTimeout(seconds) => set_timeout(env, seconds),
                     PluginCommand::ExecCmd(command_line) => exec_cmd(env, command_line),
@@ -232,9 +256,26 @@ fn host_run_plugin_command(caller: Caller<'_, PluginEnv>) {
                     PluginCommand::OpenTerminalInPlace(cwd) => {
                         open_terminal_in_place(env, cwd.path.try_into()?)
                     },
+                    PluginCommand::OpenTerminalInPlaceOfPlugin(cwd, close_plugin_after_replace) => {
+                        open_terminal_in_place_of_plugin(
+                            env,
+                            cwd.path.try_into()?,
+                            close_plugin_after_replace,
+                        )
+                    },
                     PluginCommand::OpenCommandPaneInPlace(command_to_run, context) => {
                         open_command_pane_in_place(env, command_to_run, context)
                     },
+                    PluginCommand::OpenCommandPaneInPlaceOfPlugin(
+                        command_to_run,
+                        close_plugin_after_replace,
+                        context,
+                    ) => open_command_pane_in_place_of_plugin(
+                        env,
+                        command_to_run,
+                        close_plugin_after_replace,
+                        context,
+                    ),
                     PluginCommand::RenameSession(new_session_name) => {
                         rename_session(env, new_session_name)
                     },
@@ -352,6 +393,47 @@ fn host_run_plugin_command(caller: Caller<'_, PluginEnv>) {
                         write_config_to_disk,
                     } => rebind_keys(env, keys_to_rebind, keys_to_unbind, write_config_to_disk)?,
                     PluginCommand::ListClients => list_clients(env),
+                    PluginCommand::ChangeHostFolder(new_host_folder) => {
+                        change_host_folder(env, new_host_folder)
+                    },
+                    PluginCommand::SetFloatingPanePinned(pane_id, should_be_pinned) => {
+                        set_floating_pane_pinned(env, pane_id.into(), should_be_pinned)
+                    },
+                    PluginCommand::StackPanes(pane_ids) => {
+                        stack_panes(env, pane_ids.into_iter().map(|p_id| p_id.into()).collect())
+                    },
+                    PluginCommand::ChangeFloatingPanesCoordinates(pane_ids_and_coordinates) => {
+                        change_floating_panes_coordinates(
+                            env,
+                            pane_ids_and_coordinates
+                                .into_iter()
+                                .map(|(p_id, coordinates)| (p_id.into(), coordinates))
+                                .collect(),
+                        )
+                    },
+                    PluginCommand::OpenFileNearPlugin(file_to_open, context) => {
+                        open_file_near_plugin(env, file_to_open, context)
+                    },
+                    PluginCommand::OpenFileFloatingNearPlugin(
+                        file_to_open,
+                        floating_pane_coordinates,
+                        context,
+                    ) => open_file_floating_near_plugin(
+                        env,
+                        file_to_open,
+                        floating_pane_coordinates,
+                        context,
+                    ),
+                    PluginCommand::OpenFileInPlaceOfPlugin(
+                        file_to_open,
+                        close_plugin_after_replace,
+                        context,
+                    ) => open_file_in_place_of_plugin(
+                        env,
+                        file_to_open,
+                        close_plugin_after_replace,
+                        context,
+                    ),
                 },
                 (PermissionStatus::Denied, permission) => {
                     log::error!(
@@ -577,6 +659,91 @@ fn open_file_in_place(
     apply_action!(action, error_msg, env);
 }
 
+fn open_file_near_plugin(
+    env: &PluginEnv,
+    file_to_open: FileToOpen,
+    context: BTreeMap<String, String>,
+) {
+    let cwd = file_to_open
+        .cwd
+        .map(|cwd| env.plugin_cwd.join(cwd))
+        .or_else(|| Some(env.plugin_cwd.clone()));
+    let path = env.plugin_cwd.join(file_to_open.path);
+    let open_file_payload =
+        OpenFilePayload::new(path, file_to_open.line_number, cwd).with_originating_plugin(
+            OriginatingPlugin::new(env.plugin_id, env.client_id, context),
+        );
+    let title = format!("Editing: {}", open_file_payload.path.display());
+    let should_float = false;
+    let start_suppressed = false;
+    let open_file = TerminalAction::OpenFile(open_file_payload);
+    let pty_instr = PtyInstruction::SpawnTerminal(
+        Some(open_file),
+        Some(should_float),
+        Some(title),
+        None,
+        start_suppressed,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    );
+    let _ = env.senders.send_to_pty(pty_instr);
+}
+
+fn open_file_floating_near_plugin(
+    env: &PluginEnv,
+    file_to_open: FileToOpen,
+    floating_pane_coordinates: Option<FloatingPaneCoordinates>,
+    context: BTreeMap<String, String>,
+) {
+    let cwd = file_to_open
+        .cwd
+        .map(|cwd| env.plugin_cwd.join(cwd))
+        .or_else(|| Some(env.plugin_cwd.clone()));
+    let path = env.plugin_cwd.join(file_to_open.path);
+    let open_file_payload =
+        OpenFilePayload::new(path, file_to_open.line_number, cwd).with_originating_plugin(
+            OriginatingPlugin::new(env.plugin_id, env.client_id, context),
+        );
+    let title = format!("Editing: {}", open_file_payload.path.display());
+    let should_float = true;
+    let start_suppressed = false;
+    let open_file = TerminalAction::OpenFile(open_file_payload);
+    let pty_instr = PtyInstruction::SpawnTerminal(
+        Some(open_file),
+        Some(should_float),
+        Some(title),
+        floating_pane_coordinates,
+        start_suppressed,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    );
+    let _ = env.senders.send_to_pty(pty_instr);
+}
+
+fn open_file_in_place_of_plugin(
+    env: &PluginEnv,
+    file_to_open: FileToOpen,
+    close_plugin_after_replace: bool,
+    context: BTreeMap<String, String>,
+) {
+    let cwd = file_to_open
+        .cwd
+        .map(|cwd| env.plugin_cwd.join(cwd))
+        .or_else(|| Some(env.plugin_cwd.clone()));
+    let path = env.plugin_cwd.join(file_to_open.path);
+    let open_file_payload =
+        OpenFilePayload::new(path, file_to_open.line_number, cwd).with_originating_plugin(
+            OriginatingPlugin::new(env.plugin_id, env.client_id, context),
+        );
+    let title = format!("Editing: {}", open_file_payload.path.display());
+    let open_file = TerminalAction::OpenFile(open_file_payload);
+    let pty_instr = PtyInstruction::SpawnInPlaceTerminal(
+        Some(open_file),
+        Some(title),
+        close_plugin_after_replace,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    );
+    let _ = env.senders.send_to_pty(pty_instr);
+}
+
 fn open_terminal(env: &PluginEnv, cwd: PathBuf) {
     let error_msg = || format!("failed to open file in plugin {}", env.name());
     let cwd = env.plugin_cwd.join(cwd);
@@ -595,6 +762,27 @@ fn open_terminal(env: &PluginEnv, cwd: PathBuf) {
     apply_action!(action, error_msg, env);
 }
 
+fn open_terminal_near_plugin(env: &PluginEnv, cwd: PathBuf) {
+    let cwd = env.plugin_cwd.join(cwd);
+    let should_float = false;
+    let mut default_shell = env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
+    let name = None;
+    default_shell.change_cwd(cwd);
+    let _ = env.senders.send_to_pty(PtyInstruction::SpawnTerminal(
+        Some(default_shell),
+        Some(should_float),
+        name,
+        None,
+        false,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    ));
+}
+
 fn open_terminal_floating(
     env: &PluginEnv,
     cwd: PathBuf,
@@ -617,6 +805,31 @@ fn open_terminal_floating(
     apply_action!(action, error_msg, env);
 }
 
+fn open_terminal_floating_near_plugin(
+    env: &PluginEnv,
+    cwd: PathBuf,
+    floating_pane_coordinates: Option<FloatingPaneCoordinates>,
+) {
+    let cwd = env.plugin_cwd.join(cwd);
+    let should_float = true;
+    let mut default_shell = env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
+    default_shell.change_cwd(cwd);
+    let name = None;
+    let _ = env.senders.send_to_pty(PtyInstruction::SpawnTerminal(
+        Some(default_shell),
+        Some(should_float),
+        name,
+        floating_pane_coordinates,
+        false,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    ));
+}
+
 fn open_terminal_in_place(env: &PluginEnv, cwd: PathBuf) {
     let error_msg = || format!("failed to open file in plugin {}", env.name());
     let cwd = env.plugin_cwd.join(cwd);
@@ -635,6 +848,67 @@ fn open_terminal_in_place(env: &PluginEnv, cwd: PathBuf) {
     apply_action!(action, error_msg, env);
 }
 
+fn open_terminal_in_place_of_plugin(
+    env: &PluginEnv,
+    cwd: PathBuf,
+    close_plugin_after_replace: bool,
+) {
+    let cwd = env.plugin_cwd.join(cwd);
+    let mut default_shell = env.default_shell.clone().unwrap_or_else(|| {
+        TerminalAction::RunCommand(RunCommand {
+            command: env.path_to_default_shell.clone(),
+            ..Default::default()
+        })
+    });
+    default_shell.change_cwd(cwd);
+    let name = None;
+    let _ = env
+        .senders
+        .send_to_pty(PtyInstruction::SpawnInPlaceTerminal(
+            Some(default_shell),
+            name,
+            close_plugin_after_replace,
+            ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+        ));
+}
+
+fn open_command_pane_in_place_of_plugin(
+    env: &PluginEnv,
+    command_to_run: CommandToRun,
+    close_plugin_after_replace: bool,
+    context: BTreeMap<String, String>,
+) {
+    let command = command_to_run.path;
+    let cwd = command_to_run.cwd.map(|cwd| env.plugin_cwd.join(cwd));
+    let args = command_to_run.args;
+    let direction = None;
+    let hold_on_close = true;
+    let hold_on_start = false;
+    let name = None;
+    let run_command_action = RunCommandAction {
+        command,
+        args,
+        cwd,
+        direction,
+        hold_on_close,
+        hold_on_start,
+        originating_plugin: Some(OriginatingPlugin::new(
+            env.plugin_id,
+            env.client_id,
+            context,
+        )),
+    };
+    let run_cmd = TerminalAction::RunCommand(run_command_action.into());
+    let _ = env
+        .senders
+        .send_to_pty(PtyInstruction::SpawnInPlaceTerminal(
+            Some(run_cmd),
+            name,
+            close_plugin_after_replace,
+            ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+        ));
+}
+
 fn open_command_pane(
     env: &PluginEnv,
     command_to_run: CommandToRun,
@@ -665,6 +939,43 @@ fn open_command_pane(
     apply_action!(action, error_msg, env);
 }
 
+fn open_command_pane_near_plugin(
+    env: &PluginEnv,
+    command_to_run: CommandToRun,
+    context: BTreeMap<String, String>,
+) {
+    let command = command_to_run.path;
+    let cwd = command_to_run.cwd.map(|cwd| env.plugin_cwd.join(cwd));
+    let args = command_to_run.args;
+    let direction = None;
+    let hold_on_close = true;
+    let hold_on_start = false;
+    let name = None;
+    let should_float = false;
+    let run_command_action = RunCommandAction {
+        command,
+        args,
+        cwd,
+        direction,
+        hold_on_close,
+        hold_on_start,
+        originating_plugin: Some(OriginatingPlugin::new(
+            env.plugin_id,
+            env.client_id,
+            context,
+        )),
+    };
+    let run_cmd = TerminalAction::RunCommand(run_command_action.into());
+    let _ = env.senders.send_to_pty(PtyInstruction::SpawnTerminal(
+        Some(run_cmd),
+        Some(should_float),
+        name,
+        None,
+        false,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    ));
+}
+
 fn open_command_pane_floating(
     env: &PluginEnv,
     command_to_run: CommandToRun,
@@ -696,6 +1007,44 @@ fn open_command_pane_floating(
     apply_action!(action, error_msg, env);
 }
 
+fn open_command_pane_floating_near_plugin(
+    env: &PluginEnv,
+    command_to_run: CommandToRun,
+    floating_pane_coordinates: Option<FloatingPaneCoordinates>,
+    context: BTreeMap<String, String>,
+) {
+    let command = command_to_run.path;
+    let cwd = command_to_run.cwd.map(|cwd| env.plugin_cwd.join(cwd));
+    let args = command_to_run.args;
+    let direction = None;
+    let hold_on_close = true;
+    let hold_on_start = false;
+    let name = None;
+    let should_float = true;
+    let run_command_action = RunCommandAction {
+        command,
+        args,
+        cwd,
+        direction,
+        hold_on_close,
+        hold_on_start,
+        originating_plugin: Some(OriginatingPlugin::new(
+            env.plugin_id,
+            env.client_id,
+            context,
+        )),
+    };
+    let run_cmd = TerminalAction::RunCommand(run_command_action.into());
+    let _ = env.senders.send_to_pty(PtyInstruction::SpawnTerminal(
+        Some(run_cmd),
+        Some(should_float),
+        name,
+        floating_pane_coordinates,
+        false,
+        ClientTabIndexOrPaneId::PaneId(PaneId::Plugin(env.plugin_id)),
+    ));
+}
+
 fn open_command_pane_in_place(
     env: &PluginEnv,
     command_to_run: CommandToRun,
@@ -1139,21 +1488,29 @@ fn switch_session(
             return Err(anyhow!("Failed to deserialize layout: {}", e));
         }
     }
-    let client_id = env.client_id;
-    let tab_position = tab_position.map(|p| p + 1); // ¯\_()_/¯
-    let connect_to_session = ConnectToSession {
-        name: session_name,
-        tab_position,
-        pane_id,
-        layout,
-        cwd,
-    };
-    env.senders
-        .send_to_server(ServerInstruction::SwitchSession(
-            connect_to_session,
-            client_id,
-        ))
-        .with_context(err_context)?;
+    if session_name
+        .as_ref()
+        .map(|s| s.contains('/'))
+        .unwrap_or(false)
+    {
+        log::error!("Session names cannot contain \'/\'");
+    } else {
+        let client_id = env.client_id;
+        let tab_position = tab_position.map(|p| p + 1); // ¯\_()_/¯
+        let connect_to_session = ConnectToSession {
+            name: session_name,
+            tab_position,
+            pane_id,
+            layout,
+            cwd,
+        };
+        env.senders
+            .send_to_server(ServerInstruction::SwitchSession(
+                connect_to_session,
+                client_id,
+            ))
+            .with_context(err_context)?;
+    }
     Ok(())
 }
 
@@ -1434,8 +1791,12 @@ fn rename_tab(env: &PluginEnv, tab_index: u32, new_name: &str) {
 
 fn rename_session(env: &PluginEnv, new_session_name: String) {
     let error_msg = || format!("failed to rename session in plugin {}", env.name());
-    let action = Action::RenameSession(new_session_name);
-    apply_action!(action, error_msg, env);
+    if new_session_name.contains('/') {
+        log::error!("Session names cannot contain \'/\'");
+    } else {
+        let action = Action::RenameSession(new_session_name);
+        apply_action!(action, error_msg, env);
+    }
 }
 
 fn disconnect_other_clients(env: &PluginEnv) {
@@ -1484,6 +1845,42 @@ fn list_clients(env: &PluginEnv) {
     });
 }
 
+fn change_host_folder(env: &PluginEnv, new_host_folder: PathBuf) {
+    let _ = env.senders.to_plugin.as_ref().map(|sender| {
+        sender.send(PluginInstruction::ChangePluginHostDir(
+            new_host_folder,
+            env.plugin_id,
+            env.client_id,
+        ))
+    });
+}
+
+fn set_floating_pane_pinned(env: &PluginEnv, pane_id: PaneId, should_be_pinned: bool) {
+    let _ = env.senders.to_screen.as_ref().map(|sender| {
+        sender.send(ScreenInstruction::SetFloatingPanePinned(
+            pane_id,
+            should_be_pinned,
+        ))
+    });
+}
+
+fn stack_panes(env: &PluginEnv, pane_ids: Vec<PaneId>) {
+    let _ = env
+        .senders
+        .send_to_screen(ScreenInstruction::StackPanes(pane_ids));
+}
+
+fn change_floating_panes_coordinates(
+    env: &PluginEnv,
+    pane_ids_and_coordinates: Vec<(PaneId, FloatingPaneCoordinates)>,
+) {
+    let _ = env
+        .senders
+        .send_to_screen(ScreenInstruction::ChangeFloatingPanesCoordinates(
+            pane_ids_and_coordinates,
+        ));
+}
+
 fn scan_host_folder(env: &PluginEnv, folder_to_scan: PathBuf) {
     if !folder_to_scan.starts_with("/host") {
         log::error!(
@@ -1815,14 +2212,23 @@ fn check_command_permission(
     let permission = match command {
         PluginCommand::OpenFile(..)
         | PluginCommand::OpenFileFloating(..)
+        | PluginCommand::OpenFileNearPlugin(..)
+        | PluginCommand::OpenFileFloatingNearPlugin(..)
+        | PluginCommand::OpenFileInPlaceOfPlugin(..)
         | PluginCommand::OpenFileInPlace(..) => PermissionType::OpenFiles,
         PluginCommand::OpenTerminal(..)
+        | PluginCommand::OpenTerminalNearPlugin(..)
         | PluginCommand::StartOrReloadPlugin(..)
         | PluginCommand::OpenTerminalFloating(..)
-        | PluginCommand::OpenTerminalInPlace(..) => PermissionType::OpenTerminalsOrPlugins,
+        | PluginCommand::OpenTerminalFloatingNearPlugin(..)
+        | PluginCommand::OpenTerminalInPlace(..)
+        | PluginCommand::OpenTerminalInPlaceOfPlugin(..) => PermissionType::OpenTerminalsOrPlugins,
         PluginCommand::OpenCommandPane(..)
+        | PluginCommand::OpenCommandPaneNearPlugin(..)
         | PluginCommand::OpenCommandPaneFloating(..)
+        | PluginCommand::OpenCommandPaneFloatingNearPlugin(..)
         | PluginCommand::OpenCommandPaneInPlace(..)
+        | PluginCommand::OpenCommandPaneInPlaceOfPlugin(..)
         | PluginCommand::OpenCommandPaneBackground(..)
         | PluginCommand::RunCommand(..)
         | PluginCommand::ExecCmd(..) => PermissionType::RunCommands,
@@ -1902,6 +2308,9 @@ fn check_command_permission(
         | PluginCommand::BreakPanesToTabWithIndex(..)
         | PluginCommand::ReloadPlugin(..)
         | PluginCommand::LoadNewPlugin { .. }
+        | PluginCommand::SetFloatingPanePinned(..)
+        | PluginCommand::StackPanes(..)
+        | PluginCommand::ChangeFloatingPanesCoordinates(..)
         | PluginCommand::KillSessions(..) => PermissionType::ChangeApplicationState,
         PluginCommand::UnblockCliPipeInput(..)
         | PluginCommand::BlockCliPipeInput(..)
@@ -1913,6 +2322,7 @@ fn check_command_permission(
         PluginCommand::RebindKeys { .. } | PluginCommand::Reconfigure(..) => {
             PermissionType::Reconfigure
         },
+        PluginCommand::ChangeHostFolder(..) => PermissionType::FullHdAccess,
         _ => return (PermissionStatus::Granted, None),
     };
 
