@@ -61,6 +61,9 @@ impl SwapLayouts {
     pub fn set_is_tiled_damaged(&mut self) {
         self.is_tiled_damaged = true;
     }
+    pub fn reset_floating_damage(&mut self) {
+        self.is_floating_damaged = false;
+    }
     pub fn is_floating_damaged(&self) -> bool {
         self.is_floating_damaged
     }
@@ -244,12 +247,18 @@ impl SwapLayouts {
                 Some(swap_layout) => {
                     for (constraint, layout) in swap_layout.0.iter() {
                         if self.state_fits_tiled_panes_constraint(constraint, tiled_panes) {
+                            let focus_layout_if_not_focused = true;
                             let display_area = self.display_area.borrow();
                             // TODO: reuse the assets from position_panes_in_space here?
                             let pane_count = tiled_panes.visible_panes_count();
                             let display_area = PaneGeom::from(&*display_area);
                             if layout
-                                .position_panes_in_space(&display_area, Some(pane_count), false)
+                                .position_panes_in_space(
+                                    &display_area,
+                                    Some(pane_count),
+                                    false,
+                                    focus_layout_if_not_focused,
+                                )
                                 .is_ok()
                             {
                                 return Some(layout.clone());
@@ -268,25 +277,4 @@ impl SwapLayouts {
         }
         None
     }
-    pub fn best_effort_tiled_layout(
-        &mut self,
-        tiled_panes: &TiledPanes,
-    ) -> Option<TiledPaneLayout> {
-        for swap_layout in self.swap_tiled_layouts.iter() {
-            for (_constraint, layout) in swap_layout.0.iter() {
-                let display_area = self.display_area.borrow();
-                // TODO: reuse the assets from position_panes_in_space here?
-                let pane_count = tiled_panes.visible_panes_count();
-                let display_area = PaneGeom::from(&*display_area);
-                if layout
-                    .position_panes_in_space(&display_area, Some(pane_count), false)
-                    .is_ok()
-                {
-                    return Some(layout.clone());
-                }
-            }
-        }
-        log::error!("Could not find layout that would fit on screen!");
-        None
-    }
 }
