@@ -1,4 +1,4 @@
-use crate::data::Palette;
+use crate::data::Styling;
 use miette::{Diagnostic, LabeledSpan, NamedSource, SourceCode};
 use serde::{Deserialize, Serialize};
 use std::collections::HashSet;
@@ -166,7 +166,7 @@ impl TryFrom<&CliArgs> for Config {
 }
 
 impl Config {
-    pub fn theme_config(&self, theme_name: Option<&String>) -> Option<Palette> {
+    pub fn theme_config(&self, theme_name: Option<&String>) -> Option<Styling> {
         match &theme_name {
             Some(theme_name) => self.themes.get_theme(theme_name).map(|theme| theme.palette),
             None => self.themes.get_theme("default").map(|theme| theme.palette),
@@ -407,8 +407,8 @@ impl Config {
 #[cfg(test)]
 mod config_test {
     use super::*;
-    use crate::data::{InputMode, Palette, PaletteColor};
-    use crate::input::layout::RunPlugin;
+    use crate::data::{InputMode, Palette, PaletteColor, PluginTag, StyleDeclaration, Styling};
+    use crate::input::layout::{RunPlugin, RunPluginLocation};
     use crate::input::options::{Clipboard, OnForceClose};
     use crate::input::theme::{FrameConfig, Theme, Themes, UiConfig};
     use std::collections::{BTreeMap, HashMap};
@@ -630,7 +630,8 @@ mod config_test {
                     black: PaletteColor::Rgb((0, 0, 0)),
                     white: PaletteColor::Rgb((255, 255, 255)),
                     ..Default::default()
-                },
+                }
+                .into(),
                 sourced_from_external_file: false,
             },
         );
@@ -688,7 +689,8 @@ mod config_test {
                     black: PaletteColor::Rgb((0, 0, 0)),
                     white: PaletteColor::Rgb((255, 255, 255)),
                     ..Default::default()
-                },
+                }
+                .into(),
                 sourced_from_external_file: false,
             },
         );
@@ -708,7 +710,8 @@ mod config_test {
                     white: PaletteColor::Rgb((229, 233, 240)),
                     orange: PaletteColor::Rgb((208, 135, 112)),
                     ..Default::default()
-                },
+                }
+                .into(),
                 sourced_from_external_file: false,
             },
         );
@@ -753,7 +756,8 @@ mod config_test {
                     black: PaletteColor::EightBit(1),
                     white: PaletteColor::EightBit(255),
                     ..Default::default()
-                },
+                }
+                .into(),
                 sourced_from_external_file: false,
             },
         );
@@ -761,6 +765,304 @@ mod config_test {
         assert_eq!(config.themes, expected_themes, "Theme defined in config");
     }
 
+    #[test]
+    fn can_define_style_for_theme_with_hex() {
+        let config_contents = r##"
+            themes {
+                named_theme {
+                    text_unselected {
+                        base "#DCD7BA"
+                        emphasis_0 "#DCD7CD"
+                        emphasis_1 "#DCD8DD"
+                        emphasis_2 "#DCD899"
+                        emphasis_3 "#ACD7CD"
+                        background   "#1F1F28"
+                    }
+                    text_selected {
+                        base "#16161D"
+                        emphasis_0 "#16161D"
+                        emphasis_1 "#16161D"
+                        emphasis_2 "#16161D"
+                        emphasis_3 "#16161D"
+                        background   "#9CABCA"
+                    }
+                    ribbon_unselected {
+                        base "#DCD7BA"
+                        emphasis_0 "#7FB4CA"
+                        emphasis_1 "#A3D4D5"
+                        emphasis_2 "#7AA89F"
+                        emphasis_3 "#DCD819"
+                        background   "#252535"
+                    }
+                    ribbon_selected {
+                        base "#16161D"
+                        emphasis_0 "#181820"
+                        emphasis_1 "#1A1A22"
+                        emphasis_2 "#2A2A37"
+                        emphasis_3 "#363646"
+                        background   "#76946A"
+                    }
+                    table_title {
+                        base "#DCD7BA"
+                        emphasis_0 "#7FB4CA"
+                        emphasis_1 "#A3D4D5"
+                        emphasis_2 "#7AA89F"
+                        emphasis_3 "#DCD819"
+                        background   "#252535"
+                    }
+                    table_cell_unselected {
+                        base "#DCD7BA"
+                        emphasis_0 "#DCD7CD"
+                        emphasis_1 "#DCD8DD"
+                        emphasis_2 "#DCD899"
+                        emphasis_3 "#ACD7CD"
+                        background   "#1F1F28"
+                    }
+                    table_cell_selected {
+                        base "#16161D"
+                        emphasis_0 "#181820"
+                        emphasis_1 "#1A1A22"
+                        emphasis_2 "#2A2A37"
+                        emphasis_3 "#363646"
+                        background   "#76946A"
+                    }
+                    list_unselected {
+                        base "#DCD7BA"
+                        emphasis_0 "#DCD7CD"
+                        emphasis_1 "#DCD8DD"
+                        emphasis_2 "#DCD899"
+                        emphasis_3 "#ACD7CD"
+                        background   "#1F1F28"
+                    }
+                    list_selected {
+                        base "#16161D"
+                        emphasis_0 "#181820"
+                        emphasis_1 "#1A1A22"
+                        emphasis_2 "#2A2A37"
+                        emphasis_3 "#363646"
+                        background   "#76946A"
+                    }
+                    frame_unselected {
+                        base "#DCD8DD"
+                        emphasis_0 "#7FB4CA"
+                        emphasis_1 "#A3D4D5"
+                        emphasis_2 "#7AA89F"
+                        emphasis_3 "#DCD819"
+                    }
+                    frame_selected {
+                        base "#76946A"
+                        emphasis_0 "#C34043"
+                        emphasis_1 "#C8C093"
+                        emphasis_2 "#ACD7CD"
+                        emphasis_3 "#DCD819"
+                    }
+                    exit_code_success {
+                        base "#76946A"
+                        emphasis_0 "#76946A"
+                        emphasis_1 "#76946A"
+                        emphasis_2 "#76946A"
+                        emphasis_3 "#76946A"
+                    }
+                    exit_code_error {
+                        base "#C34043"
+                        emphasis_0 "#C34043"
+                        emphasis_1 "#C34043"
+                        emphasis_2 "#C34043"
+                        emphasis_3 "#C34043"
+                    }
+                }
+            }
+            "##;
+
+        let config = Config::from_kdl(config_contents, None).unwrap();
+        let mut expected_themes = HashMap::new();
+        expected_themes.insert(
+            "named_theme".into(),
+            Theme {
+                sourced_from_external_file: false,
+                palette: Styling {
+                    text_unselected: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((220, 215, 205)),
+                        emphasis_1: PaletteColor::Rgb((220, 216, 221)),
+                        emphasis_2: PaletteColor::Rgb((220, 216, 153)),
+                        emphasis_3: PaletteColor::Rgb((172, 215, 205)),
+                        background: PaletteColor::Rgb((31, 31, 40)),
+                    },
+                    text_selected: StyleDeclaration {
+                        base: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_0: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_1: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_2: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_3: PaletteColor::Rgb((22, 22, 29)),
+                        background: PaletteColor::Rgb((156, 171, 202)),
+                    },
+                    ribbon_unselected: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((127, 180, 202)),
+                        emphasis_1: PaletteColor::Rgb((163, 212, 213)),
+                        emphasis_2: PaletteColor::Rgb((122, 168, 159)),
+                        emphasis_3: PaletteColor::Rgb((220, 216, 25)),
+                        background: PaletteColor::Rgb((37, 37, 53)),
+                    },
+                    ribbon_selected: StyleDeclaration {
+                        base: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_0: PaletteColor::Rgb((24, 24, 32)),
+                        emphasis_1: PaletteColor::Rgb((26, 26, 34)),
+                        emphasis_2: PaletteColor::Rgb((42, 42, 55)),
+                        emphasis_3: PaletteColor::Rgb((54, 54, 70)),
+                        background: PaletteColor::Rgb((118, 148, 106)),
+                    },
+                    table_title: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((127, 180, 202)),
+                        emphasis_1: PaletteColor::Rgb((163, 212, 213)),
+                        emphasis_2: PaletteColor::Rgb((122, 168, 159)),
+                        emphasis_3: PaletteColor::Rgb((220, 216, 25)),
+                        background: PaletteColor::Rgb((37, 37, 53)),
+                    },
+                    table_cell_unselected: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((220, 215, 205)),
+                        emphasis_1: PaletteColor::Rgb((220, 216, 221)),
+                        emphasis_2: PaletteColor::Rgb((220, 216, 153)),
+                        emphasis_3: PaletteColor::Rgb((172, 215, 205)),
+                        background: PaletteColor::Rgb((31, 31, 40)),
+                    },
+                    table_cell_selected: StyleDeclaration {
+                        base: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_0: PaletteColor::Rgb((24, 24, 32)),
+                        emphasis_1: PaletteColor::Rgb((26, 26, 34)),
+                        emphasis_2: PaletteColor::Rgb((42, 42, 55)),
+                        emphasis_3: PaletteColor::Rgb((54, 54, 70)),
+                        background: PaletteColor::Rgb((118, 148, 106)),
+                    },
+                    list_unselected: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((220, 215, 205)),
+                        emphasis_1: PaletteColor::Rgb((220, 216, 221)),
+                        emphasis_2: PaletteColor::Rgb((220, 216, 153)),
+                        emphasis_3: PaletteColor::Rgb((172, 215, 205)),
+                        background: PaletteColor::Rgb((31, 31, 40)),
+                    },
+                    list_selected: StyleDeclaration {
+                        base: PaletteColor::Rgb((22, 22, 29)),
+                        emphasis_0: PaletteColor::Rgb((24, 24, 32)),
+                        emphasis_1: PaletteColor::Rgb((26, 26, 34)),
+                        emphasis_2: PaletteColor::Rgb((42, 42, 55)),
+                        emphasis_3: PaletteColor::Rgb((54, 54, 70)),
+                        background: PaletteColor::Rgb((118, 148, 106)),
+                    },
+                    frame_unselected: Some(StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 216, 221)),
+                        emphasis_0: PaletteColor::Rgb((127, 180, 202)),
+                        emphasis_1: PaletteColor::Rgb((163, 212, 213)),
+                        emphasis_2: PaletteColor::Rgb((122, 168, 159)),
+                        emphasis_3: PaletteColor::Rgb((220, 216, 25)),
+                        ..Default::default()
+                    }),
+                    frame_selected: StyleDeclaration {
+                        base: PaletteColor::Rgb((118, 148, 106)),
+                        emphasis_0: PaletteColor::Rgb((195, 64, 67)),
+                        emphasis_1: PaletteColor::Rgb((200, 192, 147)),
+                        emphasis_2: PaletteColor::Rgb((172, 215, 205)),
+                        emphasis_3: PaletteColor::Rgb((220, 216, 25)),
+                        ..Default::default()
+                    },
+                    exit_code_success: StyleDeclaration {
+                        base: PaletteColor::Rgb((118, 148, 106)),
+                        emphasis_0: PaletteColor::Rgb((118, 148, 106)),
+                        emphasis_1: PaletteColor::Rgb((118, 148, 106)),
+                        emphasis_2: PaletteColor::Rgb((118, 148, 106)),
+                        emphasis_3: PaletteColor::Rgb((118, 148, 106)),
+                        ..Default::default()
+                    },
+                    exit_code_error: StyleDeclaration {
+                        base: PaletteColor::Rgb((195, 64, 67)),
+                        emphasis_0: PaletteColor::Rgb((195, 64, 67)),
+                        emphasis_1: PaletteColor::Rgb((195, 64, 67)),
+                        emphasis_2: PaletteColor::Rgb((195, 64, 67)),
+                        emphasis_3: PaletteColor::Rgb((195, 64, 67)),
+                        ..Default::default()
+                    },
+                    ..Default::default()
+                },
+            },
+        );
+        let expected_themes = Themes::from_data(expected_themes);
+        assert_eq!(config.themes, expected_themes, "Theme defined in config")
+    }
+
+    #[test]
+    fn omitting_required_style_errors() {
+        let config_contents = r##"
+            themes {
+                named_theme {
+                    text_unselected {
+                        base "#DCD7BA"
+                        emphasis_1 "#DCD8DD"
+                        emphasis_2 "#DCD899"
+                        emphasis_3 "#ACD7CD"
+                        background   "#1F1F28"
+                    }
+                }
+            }
+            "##;
+
+        let config = Config::from_kdl(config_contents, None);
+        assert!(config.is_err());
+        if let Err(ConfigError::KdlError(KdlError {
+            error_message,
+            src: _,
+            offset: _,
+            len: _,
+            help_message: _,
+        })) = config
+        {
+            assert_eq!(error_message, "Missing theme color: emphasis_0")
+        }
+    }
+
+    #[test]
+    fn partial_declaration_of_styles_defaults_omitted() {
+        let config_contents = r##"
+            themes {
+                named_theme {
+                    text_unselected {
+                        base "#DCD7BA"
+                        emphasis_0 "#DCD7CD"
+                        emphasis_1 "#DCD8DD"
+                        emphasis_2 "#DCD899"
+                        emphasis_3 "#ACD7CD"
+                        background   "#1F1F28"
+                    }
+                }
+            }
+            "##;
+
+        let config = Config::from_kdl(config_contents, None).unwrap();
+        let mut expected_themes = HashMap::new();
+        expected_themes.insert(
+            "named_theme".into(),
+            Theme {
+                sourced_from_external_file: false,
+                palette: Styling {
+                    text_unselected: StyleDeclaration {
+                        base: PaletteColor::Rgb((220, 215, 186)),
+                        emphasis_0: PaletteColor::Rgb((220, 215, 205)),
+                        emphasis_1: PaletteColor::Rgb((220, 216, 221)),
+                        emphasis_2: PaletteColor::Rgb((220, 216, 153)),
+                        emphasis_3: PaletteColor::Rgb((172, 215, 205)),
+                        background: PaletteColor::Rgb((31, 31, 40)),
+                    },
+                    ..Default::default()
+                },
+            },
+        );
+        let expected_themes = Themes::from_data(expected_themes);
+        assert_eq!(config.themes, expected_themes, "Theme defined in config")
+    }
+
     #[test]
     fn can_define_plugin_configuration_in_configfile() {
         let config_contents = r#"
