@@ -433,7 +433,7 @@ impl RunPlugin {
     }
 }
 
-#[derive(Debug, Serialize, Deserialize, Clone, Hash, Default, Eq)]
+#[derive(Debug, Serialize, Deserialize, Clone, Default, Eq)]
 pub struct PluginAlias {
     pub name: String,
     pub configuration: Option<PluginUserConfiguration>,
@@ -443,10 +443,19 @@ pub struct PluginAlias {
 
 impl PartialEq for PluginAlias {
     fn eq(&self, other: &Self) -> bool {
+        // NOTE: Keep this in sync with what the `Hash` trait impl does.
         self.name == other.name && self.configuration == other.configuration
     }
 }
 
+impl std::hash::Hash for PluginAlias {
+    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
+        // NOTE: Keep this in sync with what the `PartiqlEq` trait impl does.
+        self.name.hash(state);
+        self.configuration.hash(state);
+    }
+}
+
 impl PluginAlias {
     pub fn new(
         name: &str,
@@ -738,10 +747,12 @@ pub struct FloatingPaneLayout {
     pub width: Option<PercentOrFixed>,
     pub x: Option<PercentOrFixed>,
     pub y: Option<PercentOrFixed>,
+    pub pinned: Option<bool>,
     pub run: Option<Run>,
     pub focus: Option<bool>,
     pub already_running: bool,
     pub pane_initial_contents: Option<String>,
+    pub logical_position: Option<usize>,
 }
 
 impl FloatingPaneLayout {
@@ -752,10 +763,12 @@ impl FloatingPaneLayout {
             width: None,
             x: None,
             y: None,
+            pinned: None,
             run: None,
             focus: None,
             already_running: false,
             pane_initial_contents: None,
+            logical_position: None,
         }
     }
     pub fn add_cwd_to_layout(&mut self, cwd: &PathBuf) {
@@ -875,6 +888,7 @@ impl TiledPaneLayout {
         space: &PaneGeom,
         max_panes: Option<usize>,
         ignore_percent_split_sizes: bool,
+        focus_layout_if_not_focused: bool,
     ) -> Result<Vec<(TiledPaneLayout, PaneGeom)>, &'static str> {
         let layouts = match max_panes {
             Some(max_panes) => {
@@ -887,7 +901,7 @@ impl TiledPaneLayout {
                     // because we really should support that
                     let children_count = (max_panes - pane_count_in_layout) + 1;
                     let mut extra_children = vec![TiledPaneLayout::default(); children_count];
-                    if !layout_to_split.has_focused_node() {
+                    if !layout_to_split.has_focused_node() && focus_layout_if_not_focused {
                         if let Some(last_child) = extra_children.last_mut() {
                             last_child.focus = Some(true);
                         }
@@ -896,13 +910,29 @@ impl TiledPaneLayout {
                 } else {
                     layout_to_split.truncate(max_panes);
                 }
-                if !layout_to_split.has_focused_node() {
+                if !layout_to_split.has_focused_node() && focus_layout_if_not_focused {
                     layout_to_split.focus_deepest_pane();
                 }
 
-                split_space(space, &layout_to_split, space, ignore_percent_split_sizes)?
+                let mut stack_id = 0;
+                split_space(
+                    space,
+                    &layout_to_split,
+                    space,
+                    ignore_percent_split_sizes,
+                    &mut stack_id,
+                )?
+            },
+            None => {
+                let mut stack_id = 0;
+                split_space(
+                    space,
+                    self,
+                    space,
+                    ignore_percent_split_sizes,
+                    &mut stack_id,
+                )?
             },
-            None => split_space(space, self, space, ignore_percent_split_sizes)?,
         };
         for (_pane_layout, pane_geom) in layouts.iter() {
             if !pane_geom.is_at_least_minimum_size() {
@@ -918,10 +948,17 @@ impl TiledPaneLayout {
         if self.children.is_empty() {
             run_instructions.push(self.run.clone());
         }
+        let mut run_instructions_of_children = vec![];
         for child in &self.children {
             let mut child_run_instructions = child.extract_run_instructions();
-            run_instructions.append(&mut child_run_instructions);
+            // add the only first child to run_instructions only adding the others after all the
+            // childfree panes have been added so that the returned vec will be sorted breadth-first
+            if !child_run_instructions.is_empty() {
+                run_instructions.push(child_run_instructions.remove(0));
+            }
+            run_instructions_of_children.append(&mut child_run_instructions);
         }
+        run_instructions.append(&mut run_instructions_of_children);
         let mut successfully_ignored = 0;
         for instruction_to_ignore in &self.run_instructions_to_ignore {
             if let Some(position) = run_instructions
@@ -1120,10 +1157,7 @@ impl Layout {
             .or_else(|| default_layout_dir())
             .and_then(|layout_dir| match std::fs::read_dir(layout_dir) {
                 Ok(layout_files) => Some(layout_files),
-                Err(e) => {
-                    log::error!("Failed to read layout dir: {:?}", e);
-                    None
-                },
+                Err(_) => None,
             })
             .map(|layout_files| {
                 let mut available_layouts = vec![];
@@ -1597,6 +1631,7 @@ fn split_space(
     layout: &TiledPaneLayout,
     total_space_to_split: &PaneGeom,
     ignore_percent_split_sizes: bool,
+    next_stack_id: &mut usize,
 ) -> Result<Vec<(TiledPaneLayout, PaneGeom)>, &'static str> {
     let sizes: Vec<Option<SplitSize>> = if layout.children_are_stacked {
         let index_of_expanded_pane = layout.children.iter().position(|p| p.is_expanded_in_stack);
@@ -1610,6 +1645,11 @@ fn split_space(
         } else if let Some(last_size) = sizes.last_mut() {
             *last_size = None;
         }
+        if sizes.len() > space_to_split.rows.as_usize().saturating_sub(3) {
+            // 4 is MIN_TERMINAL_HEIGHT, minus 1 because sizes also includes the expanded pane in
+            // the stack
+            return Err("Not enough room for stacked panes in this layout");
+        }
         sizes
     } else if ignore_percent_split_sizes {
         layout
@@ -1661,6 +1701,13 @@ fn split_space(
             acc
         }
     });
+    let stacked = if layout.children_are_stacked {
+        let stack_id = *next_stack_id;
+        *next_stack_id += 1;
+        Some(stack_id)
+    } else {
+        None
+    };
 
     let mut total_pane_size = 0;
     for (&size, _part) in sizes.iter().zip(&*layout.children) {
@@ -1696,14 +1743,18 @@ fn split_space(
                 y: space_to_split.y,
                 cols: split_dimension,
                 rows: inherited_dimension,
-                is_stacked: layout.children_are_stacked,
+                stacked,
+                is_pinned: false,
+                logical_position: None,
             },
             SplitDirection::Horizontal => PaneGeom {
                 x: space_to_split.x,
                 y: current_position,
                 cols: inherited_dimension,
                 rows: split_dimension,
-                is_stacked: layout.children_are_stacked,
+                stacked,
+                is_pinned: false,
+                logical_position: None,
             },
         };
         split_geom.push(geom);
@@ -1716,6 +1767,7 @@ fn split_space(
         layout.children_split_direction,
     );
     let mut pane_positions = Vec::new();
+    let mut pane_positions_with_children = Vec::new();
     for (i, part) in layout.children.iter().enumerate() {
         let part_position_and_size = split_geom.get(i).unwrap();
         if !part.children.is_empty() {
@@ -1724,13 +1776,20 @@ fn split_space(
                 part,
                 total_space_to_split,
                 ignore_percent_split_sizes,
+                next_stack_id,
             )?;
-            pane_positions.append(&mut part_positions);
+            // add the only first child to pane_positions only adding the others after all the
+            // childfree panes have been added so that the returned vec will be sorted breadth-first
+            if !part_positions.is_empty() {
+                pane_positions.push(part_positions.remove(0));
+            }
+            pane_positions_with_children.append(&mut part_positions);
         } else {
             let part = part.clone();
             pane_positions.push((part, *part_position_and_size));
         }
     }
+    pane_positions.append(&mut pane_positions_with_children);
     if pane_positions.is_empty() {
         let layout = layout.clone();
         pane_positions.push((layout, space_to_split.clone()));
