@@ -1,6 +1,6 @@
 use super::super::actions::*;
 use super::super::keybinds::*;
-use crate::data::{self, CharOrArrow, Direction, Key};
+use crate::data::{BareKey, Direction, KeyWithModifier};
 use crate::input::config::Config;
 use insta::assert_snapshot;
 use strum::IntoEnumIterator;
@@ -15,9 +15,10 @@ fn can_define_keybindings_in_configfile() {
         }
     "#;
     let config = Config::from_kdl(config_contents, None).unwrap();
-    let ctrl_g_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('g'));
+    let ctrl_g_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
     assert_eq!(
         ctrl_g_normal_mode_action,
         Some(&vec![Action::SwitchToMode(InputMode::Locked)]),
@@ -37,11 +38,12 @@ fn can_define_multiple_keybinds_for_same_action() {
     let config = Config::from_kdl(config_contents, None).unwrap();
     let alt_h_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
         &InputMode::Normal,
-        &Key::Alt(CharOrArrow::Direction(data::Direction::Left)),
+        &KeyWithModifier::new(BareKey::Left).with_alt_modifier(),
+    );
+    let alt_left_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('h')).with_alt_modifier(),
     );
-    let alt_left_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Alt(CharOrArrow::Char('h')));
     assert_eq!(
         alt_h_normal_mode_action,
         Some(&vec![Action::MoveFocusOrTab(Direction::Left)]),
@@ -66,7 +68,7 @@ fn can_define_series_of_actions_for_same_keybinding() {
     let config = Config::from_kdl(config_contents, None).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     assert_eq!(
         z_in_pane_mode,
         Some(&vec![
@@ -90,7 +92,7 @@ fn keybindings_bind_order_is_preserved() {
     let config = Config::from_kdl(config_contents, None).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     assert_eq!(
         z_in_pane_mode,
         Some(&vec![Action::SwitchToMode(InputMode::Resize)]),
@@ -111,10 +113,10 @@ fn uppercase_and_lowercase_keybindings_are_distinct() {
     let config = Config::from_kdl(config_contents, None).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     let uppercase_z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('Z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('Z')));
     assert_eq!(
         z_in_pane_mode,
         Some(&vec![
@@ -150,7 +152,7 @@ fn can_override_keybindings() {
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     assert_eq!(
         z_in_pane_mode,
         Some(&vec![Action::SwitchToMode(InputMode::Resize)]),
@@ -180,10 +182,10 @@ fn can_add_to_default_keybindings() {
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     let r_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('r')));
     assert_eq!(
         z_in_pane_mode,
         Some(&vec![
@@ -223,18 +225,20 @@ fn can_clear_default_keybindings() {
     "#;
     let default_config = Config::from_kdl(default_config_contents, None).unwrap();
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
-    let ctrl_g_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('g'));
+    let ctrl_g_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
-    let ctrl_r_in_normal_mode = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
+    let ctrl_r_in_normal_mode = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('r')).with_ctrl_modifier(),
+    );
     let r_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('r')));
     assert_eq!(
         ctrl_g_normal_mode_action, None,
         "Keybinding from normal mode in default config cleared"
@@ -276,15 +280,16 @@ fn can_clear_default_keybindings_per_single_mode() {
     "#;
     let default_config = Config::from_kdl(default_config_contents, None).unwrap();
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
-    let ctrl_g_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('g'));
+    let ctrl_g_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     let r_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('r')));
     assert_eq!(
         ctrl_g_normal_mode_action,
         Some(&vec![Action::SwitchToMode(InputMode::Locked)]),
@@ -325,21 +330,23 @@ fn can_unbind_multiple_keys_globally() {
     "#;
     let default_config = Config::from_kdl(default_config_contents, None).unwrap();
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
-    let ctrl_g_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('g'));
-    let ctrl_g_pane_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Ctrl('g'));
+    let ctrl_g_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
+    let ctrl_g_pane_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Pane,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
     let r_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('r')));
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     let t_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('t'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('t')));
     assert_eq!(
         ctrl_g_normal_mode_action, None,
         "First keybind uncleared in one mode"
@@ -385,21 +392,23 @@ fn can_unbind_multiple_keys_per_single_mode() {
     "#;
     let default_config = Config::from_kdl(default_config_contents, None).unwrap();
     let config = Config::from_kdl(config_contents, Some(default_config)).unwrap();
-    let ctrl_g_normal_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Normal, &Key::Ctrl('g'));
-    let ctrl_g_pane_mode_action = config
-        .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Ctrl('g'));
+    let ctrl_g_normal_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Normal,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
+    let ctrl_g_pane_mode_action = config.keybinds.get_actions_for_key_in_mode(
+        &InputMode::Pane,
+        &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+    );
     let r_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('r'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('r')));
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     let t_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('t'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('t')));
     assert_eq!(
         ctrl_g_normal_mode_action,
         Some(&vec![Action::SwitchToMode(InputMode::Locked)]),
@@ -436,9 +445,10 @@ fn can_define_shared_keybinds_for_all_modes() {
     "#;
     let config = Config::from_kdl(config_contents, None).unwrap();
     for mode in InputMode::iter() {
-        let action_in_mode = config
-            .keybinds
-            .get_actions_for_key_in_mode(&mode, &Key::Ctrl('g'));
+        let action_in_mode = config.keybinds.get_actions_for_key_in_mode(
+            &mode,
+            &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+        );
         assert_eq!(
             action_in_mode,
             Some(&vec![Action::SwitchToMode(InputMode::Locked)]),
@@ -458,9 +468,10 @@ fn can_define_shared_keybinds_with_exclusion() {
     "#;
     let config = Config::from_kdl(config_contents, None).unwrap();
     for mode in InputMode::iter() {
-        let action_in_mode = config
-            .keybinds
-            .get_actions_for_key_in_mode(&mode, &Key::Ctrl('g'));
+        let action_in_mode = config.keybinds.get_actions_for_key_in_mode(
+            &mode,
+            &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+        );
         if mode == InputMode::Locked {
             assert_eq!(action_in_mode, None, "Keybind unbound in excluded mode");
         } else {
@@ -484,9 +495,10 @@ fn can_define_shared_keybinds_with_inclusion() {
     "#;
     let config = Config::from_kdl(config_contents, None).unwrap();
     for mode in InputMode::iter() {
-        let action_in_mode = config
-            .keybinds
-            .get_actions_for_key_in_mode(&mode, &Key::Ctrl('g'));
+        let action_in_mode = config.keybinds.get_actions_for_key_in_mode(
+            &mode,
+            &KeyWithModifier::new(BareKey::Char('g')).with_ctrl_modifier(),
+        );
         if mode == InputMode::Normal || mode == InputMode::Resize || mode == InputMode::Pane {
             assert_eq!(
                 action_in_mode,
@@ -512,7 +524,7 @@ fn keybindings_unbinds_happen_after_binds() {
     let config = Config::from_kdl(config_contents, None).unwrap();
     let z_in_pane_mode = config
         .keybinds
-        .get_actions_for_key_in_mode(&InputMode::Pane, &Key::Char('z'));
+        .get_actions_for_key_in_mode(&InputMode::Pane, &KeyWithModifier::new(BareKey::Char('z')));
     assert_eq!(z_in_pane_mode, None, "Key was ultimately unbound");
 }
 
